Skip to contents

Raw rating data carried over from the legacy `misskappa` package: 10 subjects, five raters, three categories (`1`–`3`), with some ratings missing (`NA`). A minimal example for the missing-data categorical estimators.

Usage

dat.klein2018

Format

A 10 x 5 data frame; columns `rater1`–`rater5` hold category codes `1`–`3`, with `NA` marking unobserved ratings.

Carried over from the legacy `misskappa` package (Klein, 2018).

References

Klein, D. (2018). Implementing a general framework for assessing interrater agreement in Stata. The Stata Journal, 18(4), 871-901. doi:10.1177/1536867X1801800408

Examples

kappa(dat.klein2018, estimator = "ipw")
#> misskappa: estimator=ipw, weight=nominal
#>                  estimate     se  lower  upper
#> Conger             0.4301 0.1050 0.2244 0.6358
#> Fleiss             0.4054 0.1196 0.1710 0.6399
#> Brennan-Prediger   0.4204 0.1136 0.1978 0.6430